aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/Analysis/DataStructure/DSGraph.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Analysis/DataStructure/DSGraph.h')
-rw-r--r--include/llvm/Analysis/DataStructure/DSGraph.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/include/llvm/Analysis/DataStructure/DSGraph.h b/include/llvm/Analysis/DataStructure/DSGraph.h
index 2ade08be6f..d323db65ba 100644
--- a/include/llvm/Analysis/DataStructure/DSGraph.h
+++ b/include/llvm/Analysis/DataStructure/DSGraph.h
@@ -376,9 +376,15 @@ public:
const DSNodeHandle &NH2, NodeMapTy &NodeMap,
bool StrictChecking = true);
/// computeGlobalGraphMapping - Compute the mapping of nodes in the global
/// graph to nodes in this graph.
- void computeGlobalGraphMapping(NodeMapTy &NodeMap);
+ void computeGGToGMapping(NodeMapTy &NodeMap);
+
+ /// computeGToGGMapping - Compute the mapping of nodes in the graph to nodes
+ /// in the globals graph. Note that any uses of this method are probably
+ /// bugs, unless it is known that the globals graph has been merged into this
+ /// graph!
+ void computeGToGGMapping(NodeMapTy &NodeMap);
/// cloneInto - Clone the specified DSGraph into the current graph. The
@@ -376,9 +376,15 @@ public:
const DSNodeHandle &NH2, NodeMapTy &NodeMap,
bool StrictChecking = true);
- /// computeGlobalGraphMapping - Compute the mapping of nodes in the global
+ /// computeGGToGMapping - Compute the mapping of nodes in the global
/// graph to nodes in this graph.